@@ -253,14 +253,14 @@ QString GncObject::hide(QString data, unsigned int anonClass)
         break;
       case MONEY1:
         in = MyMoneyMoney(data);
-        if (data == "-1/0") in = MyMoneyMoney(0);  // spurious gnucash data - causes a crash sometimes
+        if (data == "-1/0") in = MyMoneyMoney();  // spurious gnucash data - causes a crash sometimes
         mresult = MyMoneyMoney(m_moneyHideFactor) * in;
         mresult.convert(10000);
         result = mresult.toString();
         break;
       case MONEY2:
         in = MyMoneyMoney(data);
-        if (data == "-1/0") in = MyMoneyMoney(0);
+        if (data == "-1/0") in = MyMoneyMoney();
         mresult  = MyMoneyMoney(m_moneyHideFactor) * in;
         mresult.convert(10000);
         mresult.setThousandSeparator(' ');
@@ -1382,14 +1382,16 @@ void MyMoneyGncReader::convertPrice(const GncPrice *gpr)
   if (gpr->commodity()->isCurrency()) {
     MyMoneyPrice exchangeRate(gpr->commodity()->id().toUtf8(), gpr->currency()->id().toUtf8(),
                               gpr->priceDate(), rate, i18n("Imported History"));
-    m_storage->addPrice(exchangeRate);
+    if (!exchangeRate.rate(QString()).isZero())
+      m_storage->addPrice(exchangeRate);
   } else {
     MyMoneySecurity e = m_storage->security(m_mapEquities[gpr->commodity()->id().toUtf8()]);
     if (gncdebug) qDebug() << "Searching map, key = " << gpr->commodity()->id()
       << ", found id =" << e.id().data();
     e.setTradingCurrency(gpr->currency()->id().toUtf8());
     MyMoneyPrice stockPrice(e.id(), gpr->currency()->id().toUtf8(), gpr->priceDate(), rate, i18n("Imported History"));
-    m_storage->addPrice(stockPrice);
+    if (!stockPrice.rate(QString()).isZero())
+      m_storage->addPrice(stockPrice);
     m_storage->modifySecurity(e);
   }
   signalProgress(++m_priceCount, 0);
@@ -1659,12 +1661,12 @@ void MyMoneyGncReader::convertSplit(const GncSplit *gsp)
   // 3. others (categories)
   // but keeping each in same order as gnucash
   MyMoneySecurity e;
-  MyMoneyMoney price, newPrice(0);
+  MyMoneyMoney price, newPrice;
 
   switch (splitAccount.accountGroup()) {
     case MyMoneyAccount::Asset:
       if (splitAccount.accountType() == MyMoneyAccount::Stock) {
-        split.value() == MyMoneyMoney(0) ?
+        split.value().isZero() ?
         split.setAction(MyMoneySplit::ActionAddShares) :      // free shares?
         split.setAction(MyMoneySplit::ActionBuyShares);
         m_potentialTransfer = false; // ?
@@ -1844,7 +1846,7 @@ void MyMoneyGncReader::convertTemplateSplit(const QString& schedName, const GncT
         validSlotCount++;
       }
       // validate numeric, work out sign
-      MyMoneyMoney exFormula(0);
+      MyMoneyMoney exFormula;
       exFormula.setNegativeMonetarySignPosition(MyMoneyMoney::BeforeQuantityMoney);
       QString numericTest;
       char crdr = 0 ;
