@@ -23,6 +23,7 @@
 #include <QFile>
 #include <QRegExp>
 #include <QTextStream>
+#include <QTextCodec>
 #include <QByteArray>
 
 // ----------------------------------------------------------------------------
@@ -40,6 +41,7 @@
 #include <kshell.h>
 #include <KConfigGroup>
 #include <kprocess.h>
+#include <kencodingprober.h>
 // ----------------------------------------------------------------------------
 // Project Headers
 
@@ -129,7 +131,11 @@ bool WebPriceQuote::launchNative(const QString& _symbol, const QString& _id, con
       QFile f(tmpFile);
       if (f.open(QIODevice::ReadOnly)) {
         result = true;
-        QString quote = QTextStream(&f).readAll();
+        // Find out the page encoding and convert it to unicode
+        QByteArray page = f.readAll();
+        KEncodingProber prober(KEncodingProber::Universal);
+        prober.feed(page);
+        QString quote = QTextCodec::codecForName(prober.encoding())->toUnicode(page);
         f.close();
         slotParseQuote(quote);
       } else {
@@ -407,7 +413,7 @@ const QMap<QString, WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void
   result["Gielda Papierow Wartosciowych (GPW)"] = WebPriceQuoteSource("Gielda Papierow Wartosciowych (GPW)",
       "http://stooq.com/q/?s=%1",
       QString(),                   // symbol regexp
-      "Kurs.*(\\d+\\.\\d+).*Data",    // price regexp
+      "Last.*(\\d+\\.\\d+).*Date",    // price regexp
       "(\\d{4,4}-\\d{2,2}-\\d{2,2})", // date regexp
       "%y %m %d"                   // date format
                                                                      );
