@@ -738,6 +738,9 @@ void StdTransactionEditor::createEditWidgets(void)
   connect(category, SIGNAL(createItem(const QString&, QString&)), this, SLOT(slotCreateCategory(const QString&, QString&)));
   connect(category, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
   connect(category->splitButton(), SIGNAL(clicked()), this, SLOT(slotEditSplits()));
+  // initially disable the split button since we don't have an account set
+  if (category->splitButton())
+    category->splitButton()->setDisabled(m_account.id().isEmpty());
 
   KTextEdit* memo = new KTextEdit;
   memo->setObjectName(QLatin1String("Memo"));
@@ -1852,7 +1855,7 @@ int StdTransactionEditor::slotEditSplits(void)
                                  m_account,
                                  isValidAmount,
                                  dir == KMyMoneyRegister::Deposit,
-                                 MyMoneyMoney(0),
+                                 MyMoneyMoney(),
                                  m_priceInfo,
                                  m_regForm);
       connect(dlg, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
