@@ -28,6 +28,7 @@
 
 #include <KLocalizedString>
 #include <KIconLoader>
+#include <KColorScheme>
 #include <KDebug>
 
 // ----------------------------------------------------------------------------
@@ -44,8 +45,7 @@ public:
     * The pimpl.
     */
   Private() :
-      m_file(MyMoneyFile::instance()),
-      m_lastNetWorth(0) {
+      m_file(MyMoneyFile::instance()) {
   }
 
   ~Private() {
@@ -185,11 +185,15 @@ public:
     */
   MyMoneyMoney balance(const MyMoneyAccount &account) {
     MyMoneyMoney balance;
-    // account.balance() is not compatable with stock accounts
-    if (account.isInvest())
-      balance = m_file->balance(account.id());
-    else
-      balance = account.balance();
+    // a closed account has a zero balance by definition
+    if (!account.isClosed()) {
+      // account.balance() is not compatable with stock accounts
+      if (account.isInvest())
+        balance = m_file->balance(account.id());
+      else
+        balance = account.balance();
+    }
+
     // for income and liability accounts, we reverse the sign
     switch (account.accountGroup()) {
       case MyMoneyAccount::Income:
@@ -215,6 +219,9 @@ public:
     * @see balance
     */
   MyMoneyMoney value(const MyMoneyAccount &account, const MyMoneyMoney &balance) {
+    if (account.isClosed())
+      return MyMoneyMoney();
+
     QList<MyMoneyPrice> prices;
     MyMoneySecurity security = m_file->baseCurrency();
     try {
@@ -265,9 +272,9 @@ public:
     */
   MyMoneyMoney childrenTotalValue(const QModelIndex &index) {
     if (!index.isValid())
-      return MyMoneyMoney(0);
+      return MyMoneyMoney();
 
-    MyMoneyMoney totalValue(0);
+    MyMoneyMoney totalValue;
     const QAbstractItemModel *model = index.model();
     for (int i = 0; i < model->rowCount(index); ++i) {
       QModelIndex childIndex = model->index(i, index.column(), index);
@@ -354,11 +361,19 @@ public:
     if (parentAccounItem)
       setAccountData(model, parentAccounItem->index(), m_file->account(account.parentAccountId()));
     MyMoneyMoney accountTotalValue = item->data(AccountTotalValueRole).value<MyMoneyMoney>();
+    if (account.accountGroup() == MyMoneyAccount::Liability) {
+      accountTotalValue = -accountTotalValue; // the account is a liability so change the account value sign
+    }
     MyMoneyMoney institutionValue = institutionItem->data(AccountTotalValueRole).value<MyMoneyMoney>() + accountTotalValue;
     institutionItem->setData(QVariant::fromValue(institutionValue), AccountTotalValueRole);
     institutionItem->setData(false, CleanupRole);
     QModelIndex instIndex = institutionItem->index();
     QModelIndex newIndex = model->index(instIndex.row(), instIndex.column() + TotalValue, instIndex.parent());
+    if (institutionValue.isNegative()) {
+      model->setData(newIndex, KMyMoneyGlobalSettings::listNegativeValueColor(), Qt::ForegroundRole);
+    } else {
+      model->setData(newIndex, KColorScheme(QPalette::Active).foreground(KColorScheme::NormalText).color(), Qt::ForegroundRole);
+    }
     model->setData(newIndex, institutionValue.formatMoney(m_file->baseCurrency()), Qt::DisplayRole);
     model->setData(newIndex, institutionValue.formatMoney(m_file->baseCurrency()), AccountTotalValueDisplayRole);
     model->setData(newIndex, font, Qt::FontRole);
@@ -427,9 +442,15 @@ AccountsModel::~AccountsModel()
 /**
   * This function synchronizes the data of the model with the data
   * from the @ref MyMoneyFile.
+  *
+  * @return true if a real account was actually loaded into the model
+  *         false otherwise
   */
-void AccountsModel::load()
+bool AccountsModel::load()
 {
+  // the return value
+  bool realAccountWasLoaded = false;
+
   // mark all rows as candidates for cleaning up
   QModelIndexList list = match(index(0, 0), Qt::DisplayRole, "*", -1, Qt::MatchFlags(Qt::MatchWildcard | Qt::MatchRecursive));
   foreach (const QModelIndex &index, list) {
@@ -455,9 +476,9 @@ void AccountsModel::load()
     }
     institutionItem->setData(institution.name(), Qt::DisplayRole);
     institutionItem->setData(QVariant::fromValue(institution), AccountRole);
-    institutionItem->setData(QVariant::fromValue(MyMoneyMoney(0)), AccountBalanceRole);
-    institutionItem->setData(QVariant::fromValue(MyMoneyMoney(0)), AccountValueRole);
-    institutionItem->setData(QVariant::fromValue(MyMoneyMoney(0)), AccountTotalValueRole);
+    institutionItem->setData(QVariant::fromValue(MyMoneyMoney()), AccountBalanceRole);
+    institutionItem->setData(QVariant::fromValue(MyMoneyMoney()), AccountValueRole);
+    institutionItem->setData(QVariant::fromValue(MyMoneyMoney()), AccountTotalValueRole);
     institutionItem->setData(institution.id(), AccountIdRole);
     institutionItem->setData(6, DisplayOrderRole);
     institutionItem->setColumnCount(columnCount());
@@ -550,6 +571,7 @@ void AccountsModel::load()
         d->loadSubAccounts(this, item, favoriteAccountsItem, acc.accountList());
       }
       d->setAccountData(this, item->index(), acc);
+      realAccountWasLoaded = true;
       // set the account data after the children have been loaded
       if (acc.value("PreferredAccount") == "Yes") {
         QStandardItem *item = d->itemFromAccountId(favoriteAccountsItem, acc.id());
@@ -602,7 +624,7 @@ void AccountsModel::load()
                                         1,
                                         Qt::MatchFlags(Qt::MatchExactly | Qt::MatchCaseSensitive));
 
-  MyMoneyMoney netWorth(0);
+  MyMoneyMoney netWorth;
   if (!assetList.isEmpty() && !liabilityList.isEmpty()) {
     QVariant assetValue = data(assetList.front(), AccountsModel::AccountTotalValueRole);
     QVariant liabilityValue = data(liabilityList.front(), AccountsModel::AccountTotalValueRole);
@@ -629,7 +651,7 @@ void AccountsModel::load()
                                       1,
                                       Qt::MatchFlags(Qt::MatchExactly | Qt::MatchCaseSensitive));
 
-  MyMoneyMoney profit(0);
+  MyMoneyMoney profit;
   if (!incomeList.isEmpty() && !expenseList.isEmpty()) {
     QVariant incomeValue = data(incomeList.front(), AccountsModel::AccountTotalValueRole);
     QVariant expenseValue = data(expenseList.front(), AccountsModel::AccountTotalValueRole);
@@ -642,6 +664,7 @@ void AccountsModel::load()
     d->m_lastProfit = profit;
     emit profitChanged(d->m_lastProfit);
   }
+  return realAccountWasLoaded;
 }
 
 MyMoneyMoney AccountsModel::accountValue(const MyMoneyAccount &account, const MyMoneyMoney &balance)
@@ -717,14 +740,28 @@ AccountsFilterProxyModel::~AccountsFilterProxyModel()
   */
 bool AccountsFilterProxyModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
 {
-  QVariant leftData = sourceModel()->data(left, AccountsModel::DisplayOrderRole);
-  QVariant rightData = sourceModel()->data(right, AccountsModel::DisplayOrderRole);
+  // different sorting based on the column which is being sorted
+  switch (left.column()) {
+      // for the accounts column sort based on the DisplayOrderRole
+    case AccountsModel::Account: {
+        QVariant leftData = sourceModel()->data(left, AccountsModel::DisplayOrderRole);
+        QVariant rightData = sourceModel()->data(right, AccountsModel::DisplayOrderRole);
 
-  if (leftData.toInt() == rightData.toInt()) {
-    // sort items of the same display order alphabetically
-    return QSortFilterProxyModel::lessThan(left, right);
+        if (leftData.toInt() == rightData.toInt()) {
+          // sort items of the same display order alphabetically
+          return QSortFilterProxyModel::lessThan(left, right);
+        }
+        return leftData.toInt() < rightData.toInt();
+      }
+      // the total balance and value columns are sorted based on the value of the account
+    case AccountsModel::TotalBalance:
+    case AccountsModel::TotalValue: {
+        QVariant leftData = sourceModel()->data(sourceModel()->index(left.row(), 0, left.parent()), AccountsModel::AccountTotalValueRole);
+        QVariant rightData = sourceModel()->data(sourceModel()->index(right.row(), 0, right.parent()), AccountsModel::AccountTotalValueRole);
+        return leftData.value<MyMoneyMoney>() < rightData.value<MyMoneyMoney>();
+      }
   }
-  return leftData.toInt() < rightData.toInt();
+  return QSortFilterProxyModel::lessThan(left, right);
 }
 
 /**
