@@ -93,8 +93,6 @@ public:
 
   ~AccountsModel();
 
-  void load();
-
   /**
     * Compute the value of the given account using the provided balance.
     * The value is defined as the balance of the account converted to the base currency.
@@ -110,6 +108,8 @@ public slots:
 
   void slotReconcileAccount(const MyMoneyAccount &account, const QDate &reconciliationDate, const MyMoneyMoney &endingBalance);
 
+  bool load();
+
 signals:
   /**
     * Emit this signal when the net worth based on the value of the loaded accounts is changed.
