@@ -11,30 +11,15 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef __MYMONEYPAYEETEST_H__
-#define __MYMONEYPAYEETEST_H__
+#ifndef MYMONEYPAYEETEST_H
+#define MYMONEYPAYEETEST_H
 
-#include <cppunit/extensions/HelperMacros.h>
-#include "autotest.h"
+#include <QtCore/QObject>
 
-#define private public
-#define protected public
-#include "mymoneypayee.h"
-#undef private
-#undef protected
-
-class MyMoneyPayeeTest : public CppUnit::TestFixture
+class MyMoneyPayeeTest : public QObject
 {
-  CPPUNIT_TEST_SUITE(MyMoneyPayeeTest);
-  CPPUNIT_TEST(testXml);
-  CPPUNIT_TEST(testDefaultAccount);
-  CPPUNIT_TEST_SUITE_END();
-
+  Q_OBJECT
 public:
-  MyMoneyPayeeTest();
-
-  void setUp();
-  void tearDown();
   void testXml();
   void testDefaultAccount();
 };
