@@ -69,7 +69,6 @@ MyMoneyReport::MyMoneyReport() :
     m_chartDataLabels(true),
     m_chartGridLines(true),
     m_chartByDefault(false),
-    m_chartLineWidth(2),
     m_includeSchedules(false),
     m_includeTransfers(false),
     m_includeBudgetActuals(false),
@@ -82,6 +81,7 @@ MyMoneyReport::MyMoneyReport() :
     m_mixedTime(false),
     m_currentDateColumn(0)
 {
+  m_chartLineWidth = m_lineWidth;
 }
 
 MyMoneyReport::MyMoneyReport(const QString& id, const MyMoneyReport& right) :
@@ -110,7 +110,6 @@ MyMoneyReport::MyMoneyReport(ERowType _rt, unsigned _ct, dateOptionE _dl, EDetai
     m_chartDataLabels(true),
     m_chartGridLines(true),
     m_chartByDefault(false),
-    m_chartLineWidth(2),
     m_includeSchedules(false),
     m_includeTransfers(false),
     m_includeBudgetActuals(false),
@@ -123,16 +122,22 @@ MyMoneyReport::MyMoneyReport(ERowType _rt, unsigned _ct, dateOptionE _dl, EDetai
     m_mixedTime(false),
     m_currentDateColumn(0)
 {
+  //set initial values
+  m_chartLineWidth = m_lineWidth;
+
+  //set report type
   if (m_reportType == ePivotTable)
     m_columnType = static_cast<EColumnType>(_ct);
   if (m_reportType == eQueryTable)
     m_queryColumns = static_cast<EQueryColumns>(_ct);
   setDateFilter(_dl);
 
+  //throw exception if the type is inconsistent
   if ((_rt > static_cast<ERowType>(sizeof(kTypeArray) / sizeof(kTypeArray[0])))
       || (m_reportType == eNoReport))
     throw new MYMONEYEXCEPTION("Invalid report type");
 
+  //add the corresponding account groups
   if (_rt == MyMoneyReport::eAssetLiability) {
     addAccountGroup(MyMoneyAccount::Asset);
     addAccountGroup(MyMoneyAccount::Liability);
@@ -272,28 +277,28 @@ bool MyMoneyReport::includes(const MyMoneyAccount& acc) const
 
   if (includesAccountGroup(acc.accountGroup())) {
     switch (acc.accountGroup()) {
-    case MyMoneyAccount::Income:
-    case MyMoneyAccount::Expense:
-      if (isTax())
-        result = (acc.value("Tax") == "Yes") && includesCategory(acc.id());
-      else
-        result = includesCategory(acc.id());
-      break;
-    case MyMoneyAccount::Asset:
-    case MyMoneyAccount::Liability:
-      if (isLoansOnly())
-        result = acc.isLoan() && includesAccount(acc.id());
-      else if (isInvestmentsOnly())
-        result = acc.isInvest() && includesAccount(acc.id());
-      else if (isIncludingTransfers() && m_rowType == MyMoneyReport::eExpenseIncome)
-        // If transfers are included, ONLY include this account if it is NOT
-        // included in the report itself!!
-        result = ! includesAccount(acc.id());
-      else
+      case MyMoneyAccount::Income:
+      case MyMoneyAccount::Expense:
+        if (isTax())
+          result = (acc.value("Tax") == "Yes") && includesCategory(acc.id());
+        else
+          result = includesCategory(acc.id());
+        break;
+      case MyMoneyAccount::Asset:
+      case MyMoneyAccount::Liability:
+        if (isLoansOnly())
+          result = acc.isLoan() && includesAccount(acc.id());
+        else if (isInvestmentsOnly())
+          result = acc.isInvest() && includesAccount(acc.id());
+        else if (isIncludingTransfers() && m_rowType == MyMoneyReport::eExpenseIncome)
+          // If transfers are included, ONLY include this account if it is NOT
+          // included in the report itself!!
+          result = ! includesAccount(acc.id());
+        else
+          result = includesAccount(acc.id());
+        break;
+      default:
         result = includesAccount(acc.id());
-      break;
-    default:
-      result = includesAccount(acc.id());
     }
   }
   return result;
@@ -622,7 +627,7 @@ bool MyMoneyReport::read(const QDomElement& e)
       m_chartDataLabels = e.attribute("chartdatalabels", "1").toUInt();
       m_chartGridLines = e.attribute("chartgridlines", "1").toUInt();
       m_chartByDefault = e.attribute("chartbydefault", "0").toUInt();
-      m_chartLineWidth = e.attribute("chartlinewidth", "2").toUInt();
+      m_chartLineWidth = e.attribute("chartlinewidth", QString(m_lineWidth)).toUInt();
     } else {
       m_chartDataLabels = true;
       m_chartGridLines = true;
@@ -745,4 +750,11 @@ bool MyMoneyReport::hasReferenceTo(const QString& id) const
   return (list.contains(id) > 0);
 }
 
+int MyMoneyReport::m_lineWidth = 2;
+
+void MyMoneyReport::setLineWidth(int width)
+{
+  m_lineWidth = width;
+}
+
 // vim:cin:si:ai:et:ts=2:sw=2:
