@@ -55,6 +55,8 @@ class MyMoneyStorageANON;
 class KMM_MYMONEY_EXPORT MyMoneySchedule : public MyMoneyObject
 {
   friend class MyMoneyStorageANON;
+  KMM_MYMONEY_UNIT_TESTABLE
+
 public:
   /**
     * This enum is used to describe all the possible schedule frequencies.
@@ -201,6 +203,15 @@ public:
     */
   int transactionsRemaining(void) const;
 
+  /**
+    * Simple method that returns the number of transactions remaining
+    * until a given date.
+    *
+    * @param endDate Date to count transactions to.
+    * @return int The number of transactions remaining for the instance.
+    */
+  int transactionsRemainingUntil(const QDate& endDate) const;
+
   /**
     * Simple get method that returns the schedule end date.
     *
@@ -450,6 +461,21 @@ public:
     */
   QDate nextPayment(const QDate& refDate = QDate::currentDate()) const;
 
+  /**
+    * Calculates the date of the next payment and adjusts if asked.
+    *
+    * @param adjust Whether to adjust the calculated date according to the
+    *               rules specified by the schedule's weekend option.
+    * @param refDate The reference date from which the next payment
+    *                date will be calculated (defaults to current date)
+    *
+    * @return QDate The date the next payment is due. This date is
+    *         always past @a refDate.  In case of an error or
+    *         if there is no more payments then an empty/invalid QDate()
+    *         will be returned.
+    */
+  QDate nextPaymentDate(const bool& adjust, const QDate& refDate = QDate::currentDate()) const;
+
   /**
     * Calculates the dates of the payment over a certain period of time.
     *
@@ -749,4 +775,10 @@ private:
   /// The weekend option
   weekendOptionE m_weekendOption;
 };
+
+/**
+  * Make it possible to hold @ref MyMoneySchedule objects inside @ref QVariant objects.
+  */
+Q_DECLARE_METATYPE(MyMoneySchedule)
+
 #endif
