@@ -27,12 +27,6 @@
 #define CATCH } catch (MyMoneyException *e) {
 #define PASS } catch (MyMoneyException *e) { throw; }
 
-bool MyMoneyBalanceCacheItem::operator ==(const MyMoneyBalanceCacheItem & right) const
-{
-  return ((balance == right.balance)
-          && (valid == right.valid));
-}
-
 MyMoneySeqAccessMgr::MyMoneySeqAccessMgr()
 {
   m_nextAccountID = 0;
@@ -83,15 +77,6 @@ MyMoneySeqAccessMgr::MyMoneySeqAccessMgr()
   // load account list with initial accounts
   m_accountList = map;
 
-  MyMoneyBalanceCacheItem balance;
-
-  m_balanceCache.clear();
-  m_balanceCache[STD_ACC_LIABILITY] = balance;
-  m_balanceCache[STD_ACC_ASSET] = balance;
-  m_balanceCache[STD_ACC_EXPENSE] = balance;
-  m_balanceCache[STD_ACC_INCOME] = balance;
-  m_balanceCache[STD_ACC_EQUITY] = balance;
-
   // initialize for file fixes (see kmymoneyview.cpp)
   m_currentFixVersion = 2;
   m_fileFixVersion = 0; // default value if no fix-version in file
@@ -279,8 +264,6 @@ void MyMoneySeqAccessMgr::addAccount(MyMoneyAccount& parent, MyMoneyAccount& acc
   m_accountList.modify(acc.id(), acc);
   account = acc;
 
-  MyMoneyBalanceCacheItem balance;
-  m_balanceCache[account.id()] = balance;
 }
 
 void MyMoneySeqAccessMgr::addInstitution(MyMoneyInstitution& institution)
@@ -441,7 +424,6 @@ void MyMoneySeqAccessMgr::addTransaction(MyMoneyTransaction& transaction, const
     adjustBalance(acc, *it_s);
     if (!skipAccountUpdate) {
       acc.touch();
-      invalidateBalanceCache(acc.id());
     }
     m_accountList.modify(acc.id(), acc);
   }
@@ -453,8 +435,7 @@ void MyMoneySeqAccessMgr::adjustBalance(MyMoneyAccount& acc, const MyMoneySplit&
   // amount of the split since we don't know about stock splits.
   // so in the case of those stocks, we simply recalculate the balance from scratch
   if (acc.isInvest()) {
-    invalidateBalanceCache(acc.id());
-    acc.setBalance(balance(acc.id()));
+    acc.setBalance(calculateBalance(acc.id()));
   } else {
     acc.adjustBalance(split, reverse);
   }
@@ -518,9 +499,6 @@ void MyMoneySeqAccessMgr::modifyAccount(const MyMoneyAccount& account, const boo
       // update information in account list
       m_accountList.modify(account.id(), account);
 
-      // invalidate cached balance
-      invalidateBalanceCache(account.id());
-
     } else
       throw new MYMONEYEXCEPTION("Invalid information for update");
 
@@ -583,10 +561,14 @@ void MyMoneySeqAccessMgr::modifyTransaction(const MyMoneyTransaction& transactio
 
   for (it_s = (*it_t).splits().begin(); it_s != (*it_t).splits().end(); ++it_s) {
     MyMoneyAccount acc = m_accountList[(*it_s).accountId()];
-    adjustBalance(acc, *it_s, true);
-    acc.touch();
-    invalidateBalanceCache(acc.id());
-    m_accountList.modify(acc.id(), acc);
+    // we only need to adjust non-investment accounts here
+    // as for investment accounts the balance will be recalculated
+    // after the transaction has been added.
+    if (!acc.isInvest()) {
+      adjustBalance(acc, *it_s, true);
+      acc.touch();
+      m_accountList.modify(acc.id(), acc);
+    }
   }
 
   // remove old transaction from lists
@@ -602,7 +584,6 @@ void MyMoneySeqAccessMgr::modifyTransaction(const MyMoneyTransaction& transactio
     MyMoneyAccount acc = m_accountList[(*it_s).accountId()];
     adjustBalance(acc, *it_s);
     acc.touch();
-    invalidateBalanceCache(acc.id());
     m_accountList.modify(acc.id(), acc);
   }
 }
@@ -672,23 +653,25 @@ void MyMoneySeqAccessMgr::removeTransaction(const MyMoneyTransaction& transactio
   if (it_t == m_transactionList.end())
     throw new MYMONEYEXCEPTION("invalid transaction key");
 
-  QList<MyMoneySplit>::ConstIterator it_s;
-
-  // scan the splits and collect all accounts that need
-  // to be updated after the removal of this transaction
-  for (it_s = (*it_t).splits().begin(); it_s != (*it_t).splits().end(); ++it_s) {
-    MyMoneyAccount acc = m_accountList[(*it_s).accountId()];
-    adjustBalance(acc, *it_s, true);
-    acc.touch();
-    m_accountList.modify(acc.id(), acc);
-    invalidateBalanceCache(acc.id());
-  }
+  // keep a copy so that we still have the data after removal
+  MyMoneyTransaction t(*it_t);
 
   // FIXME: check if any split is frozen and throw exception
 
   // remove the transaction from the two lists
   m_transactionList.remove(*it_k);
   m_transactionKeys.remove(transaction.id());
+
+  // scan the splits and collect all accounts that need
+  // to be updated after the removal of this transaction
+  QList<MyMoneySplit>::ConstIterator it_s;
+  for (it_s = t.splits().constBegin(); it_s != t.splits().constEnd(); ++it_s) {
+    MyMoneyAccount acc = m_accountList[(*it_s).accountId()];
+    adjustBalance(acc, *it_s, true);
+    acc.touch();
+    m_accountList.modify(acc.id(), acc);
+  }
+
 }
 
 void MyMoneySeqAccessMgr::removeAccount(const MyMoneyAccount& account)
@@ -761,10 +744,6 @@ void MyMoneySeqAccessMgr::removeAccount(const MyMoneyAccount& account)
 
     // remove account from the global account pool
     m_accountList.remove(account.id());
-
-    // remove from balance list
-    m_balanceCache.remove(account.id());
-    invalidateBalanceCache(parent.id());
   }
 }
 
@@ -888,65 +867,46 @@ const MyMoneyTransaction MyMoneySeqAccessMgr::transaction(const QString& account
 
 const MyMoneyMoney MyMoneySeqAccessMgr::balance(const QString& id, const QDate& date) const
 {
-  MyMoneyMoney result(0);
   MyMoneyAccount acc = account(id);
-  // if (date != QDate()) qDebug ("request balance for %s at %s", id.data(), date.toString(Qt::ISODate).toLatin1());
-  if (!date.isValid() && !acc.isInvest()) {
+  if (!date.isValid()) {
+    // the balance of all transactions for this account has
+    // been requested. no need to calculate anything as we
+    // have this number with the account object already.
     if (m_accountList.find(id) != m_accountList.end()) {
       return m_accountList[id].balance();
     }
-    return MyMoneyMoney(0);
+    return MyMoneyMoney();
   }
-  if (m_balanceCache[id].valid == false || date != m_balanceCacheDate || acc.isInvest()) {
-    QMap<QString, MyMoneyMoney> balances;
-    QMap<QString, MyMoneyMoney>::ConstIterator it_b;
-    if (date != m_balanceCacheDate) {
-      m_balanceCache.clear();
-      m_balanceCacheDate = date;
-    }
 
-    QList<MyMoneyTransaction> list;
-    QList<MyMoneyTransaction>::ConstIterator it_t;
-    QList<MyMoneySplit>::ConstIterator it_s;
+  return calculateBalance(id, date);
+}
 
-    MyMoneyTransactionFilter filter;
-    filter.setDateFilter(QDate(), date);
-    filter.setReportAllSplits(false);
-    transactionList(list, filter);
+MyMoneyMoney MyMoneySeqAccessMgr::calculateBalance(const QString& id, const QDate& date) const
+{
+  QMap<QString, MyMoneyMoney> balances;
+  QMap<QString, MyMoneyMoney>::ConstIterator it_b;
 
-    for (it_t = list.constBegin(); it_t != list.constEnd(); ++it_t) {
-      for (it_s = (*it_t).splits().begin(); it_s != (*it_t).splits().end(); ++it_s) {
-        const QString& aid = (*it_s).accountId();
-        if ((*it_s).action() == MyMoneySplit::ActionSplitShares) {
-          balances[aid] = balances[aid] * (*it_s).shares();
-        } else {
-          balances[aid] += (*it_s).shares();
-        }
-      }
-    }
+  QList<MyMoneyTransaction> list;
+  QList<MyMoneyTransaction>::ConstIterator it_t;
+  QList<MyMoneySplit>::ConstIterator it_s;
 
-    // fill the found balances into the cache
-    for (it_b = balances.constBegin(); it_b != balances.constEnd(); ++it_b) {
-      MyMoneyBalanceCacheItem balance(*it_b);
-      m_balanceCache[it_b.key()] = balance;
-    }
+  MyMoneyTransactionFilter filter;
+  filter.setDateFilter(QDate(), date);
+  filter.setReportAllSplits(false);
+  transactionList(list, filter);
 
-    // fill all accounts w/o transactions to zero
-    QMap<QString, MyMoneyAccount>::ConstIterator it_a;
-    for (it_a = m_accountList.begin(); it_a != m_accountList.end(); ++it_a) {
-      if (m_balanceCache[(*it_a).id()].valid == false) {
-        MyMoneyBalanceCacheItem balance(MyMoneyMoney(0, 1));
-        m_balanceCache[(*it_a).id()] = balance;
+  for (it_t = list.constBegin(); it_t != list.constEnd(); ++it_t) {
+    for (it_s = (*it_t).splits().constBegin(); it_s != (*it_t).splits().constEnd(); ++it_s) {
+      const QString& aid = (*it_s).accountId();
+      if ((*it_s).action() == MyMoneySplit::ActionSplitShares) {
+        balances[aid] = balances[aid] * (*it_s).shares();
+      } else {
+        balances[aid] += (*it_s).shares();
       }
     }
   }
 
-  if (m_balanceCache[id].valid == true)
-    result = m_balanceCache[id].balance;
-  else
-    qDebug("Cache mishit should never happen at this point");
-
-  return result;
+  return balances[id];
 }
 
 const MyMoneyMoney MyMoneySeqAccessMgr::totalBalance(const QString& id, const QDate& date) const
@@ -965,20 +925,6 @@ const MyMoneyMoney MyMoneySeqAccessMgr::totalBalance(const QString& id, const QD
   return result;
 }
 
-void MyMoneySeqAccessMgr::invalidateBalanceCache(const QString& id)
-{
-  if (!id.isEmpty()) {
-    try {
-      m_balanceCache[id].valid = false;
-      if (!isStandardAccount(id)) {
-        invalidateBalanceCache(account(id).parentAccountId());
-      }
-    } catch (MyMoneyException *e) {
-      delete e;
-    }
-  }
-}
-
 void MyMoneySeqAccessMgr::loadAccounts(const QMap<QString, MyMoneyAccount>& map)
 {
   m_accountList = map;
@@ -999,54 +945,26 @@ void MyMoneySeqAccessMgr::loadAccounts(const QMap<QString, MyMoneyAccount>& map)
 
 void MyMoneySeqAccessMgr::loadTransactions(const QMap<QString, MyMoneyTransaction>& map)
 {
+  m_transactionList = map;
 
   // now fill the key map and
   // identify the last used id
   QString lastId("");
   QMap<QString, QString> keys;
   QMap<QString, MyMoneyTransaction>::ConstIterator it_t;
-  QList<MyMoneyTransaction> duplicates;
 
   for (it_t = map.constBegin(); it_t != map.constEnd(); ++it_t) {
-    if (keys.contains((*it_t).id())) {
-      qDebug("Duplicate detected for transaction '%s'", qPrintable((*it_t).id()));
-      duplicates << (*it_t);
-    } else {
-      keys[(*it_t).id()] = it_t.key();
-      if ((*it_t).id() > lastId)
-        lastId = (*it_t).id();
-    }
+    keys[(*it_t).id()] = it_t.key();
+    if ((*it_t).id() > lastId)
+      lastId = (*it_t).id();
   }
+  m_transactionKeys = keys;
 
-  // keep track of hightes used ID so far
+  // determine highest used ID so far
   int pos = lastId.indexOf(QRegExp("\\d+"), 0);
   if (pos != -1) {
     m_nextTransactionID = lastId.mid(pos).toInt();
   }
-
-  // process duplicates
-  QList<MyMoneyTransaction>::ConstIterator it_d;
-  if (duplicates.count() > 0) {
-    QMap<QString, MyMoneyTransaction> newMap;
-    newMap = map;
-    for (it_d = duplicates.constBegin(); it_d != duplicates.constEnd(); ++it_d) {
-      // remove old reference from map
-      newMap.remove((*it_d).uniqueSortKey());
-
-      // create transaction with new id
-      MyMoneyTransaction newTransaction(nextTransactionID(), *it_d);
-      QString key = newTransaction.uniqueSortKey();
-
-      newMap[key] = newTransaction;
-      keys[newTransaction.id()] = key;
-      qDebug("Duplicate got new id '%s'", qPrintable(newTransaction.id()));
-    }
-    m_transactionList = newMap;
-  } else {
-    m_transactionList = map;
-  }
-
-  m_transactionKeys = keys;
 }
 
 void MyMoneySeqAccessMgr::loadInstitutions(const QMap<QString, MyMoneyInstitution>& map)
@@ -1754,11 +1672,6 @@ const MyMoneyPrice MyMoneySeqAccessMgr::price(const QString& fromId, const QStri
   return rc;
 }
 
-void MyMoneySeqAccessMgr::clearCache(void)
-{
-  m_balanceCache.clear();
-}
-
 void MyMoneySeqAccessMgr::rebuildAccountBalances(void)
 {
   // reset the balance of all accounts to 0
@@ -1767,7 +1680,7 @@ void MyMoneySeqAccessMgr::rebuildAccountBalances(void)
 
   QMap<QString, MyMoneyAccount>::iterator it_a;
   for (it_a = map.begin(); it_a != map.end(); ++it_a) {
-    (*it_a).setBalance(MyMoneyMoney(0));
+    (*it_a).setBalance(MyMoneyMoney());
   }
 
   // now scan over all transactions and all splits and setup the balances
