@@ -19,6 +19,10 @@
 #ifndef MYMONEYSTORAGESQL_H
 #define MYMONEYSTORAGESQL_H
 
+// ----------------------------------------------------------------------------
+// System Includes
+#include <limits>
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -105,7 +109,7 @@ private:
 
 /**
   * The MyMoneySqlQuery class is derived from QSqlQuery to provide
-  * a way to adjust some queries based on databaseTypeE and make
+  * a way to adjust some queries based on database type and make
   * debugging easier by providing a place to put debug statements.
   */
 class MyMoneySqlQuery : public QSqlQuery
@@ -129,6 +133,8 @@ class IMyMoneySerialize;
 class MyMoneyStorageSql : public IMyMoneyStorageFormat, public QSqlDatabase, public KShared
 {
   friend class MyMoneyDbDef;
+  KMM_MYMONEY_UNIT_TESTABLE
+
 public:
   explicit MyMoneyStorageSql(IMyMoneySerialize *storage, const KUrl& = KUrl());
   virtual ~MyMoneyStorageSql() {
@@ -299,9 +305,21 @@ public:
   void loadReportId(const unsigned long& id);
   void loadBudgetId(const unsigned long& id);
 
+  /**
+    * This method allows to modify the precision with which prices
+    * are handled within the object. The default of the precision is 4.
+    */
+  static void setPrecision(int prec);
+
+  /**
+    * This method allows to modify the start date for transaction retrieval
+    * The default of the precision is Jan 1st, 1900.
+    */
+  static void setStartDate(const QDate &startDate);
+
 private:
   //void init(void);
-  bool sqliteExists(const QString& dbName);
+  bool fileExists(const QString& dbName);
   // a function to build a comprehensive error message
   QString& buildError(const QSqlQuery& q, const QString& function, const QString& message) const;
   QString& buildError(const QSqlQuery& q, const QString& function, const QString& message,
@@ -320,19 +338,19 @@ private:
   void writeReports(void);
   void writeBudgets(void);
 
-  void writeInstitutionList(const QList<MyMoneyInstitution>& iList, MyMoneySqlQuery& q);
-  void writePayee(const MyMoneyPayee& p, MyMoneySqlQuery& q, bool isUserInfo = false);
-  void writeAccountList(const QList<MyMoneyAccount>& accList, MyMoneySqlQuery& q);
-  void writeTransaction(const QString& txId, const MyMoneyTransaction& tx, MyMoneySqlQuery& q, const QString& type);
+  void writeInstitutionList(const QList<MyMoneyInstitution>& iList, QSqlQuery& q);
+  void writePayee(const MyMoneyPayee& p, QSqlQuery& q, bool isUserInfo = false);
+  void writeAccountList(const QList<MyMoneyAccount>& accList, QSqlQuery& q);
+  void writeTransaction(const QString& txId, const MyMoneyTransaction& tx, QSqlQuery& q, const QString& type);
   void writeSplits(const QString& txId, const QString& type, const QList<MyMoneySplit>& splitList);
-  void writeSplitList(const QString& txId, const QList<MyMoneySplit>& splitList, const QString& type, const QList<int>& splitIdList, MyMoneySqlQuery& q);
-  void writeSchedule(const MyMoneySchedule& sch, MyMoneySqlQuery& q, bool insert);
-  void writeSecurity(const MyMoneySecurity& security, MyMoneySqlQuery& q);
+  void writeSplitList(const QString& txId, const QList<MyMoneySplit>& splitList, const QString& type, const QList<int>& splitIdList, QSqlQuery& q);
+  void writeSchedule(const MyMoneySchedule& sch, QSqlQuery& q, bool insert);
+  void writeSecurity(const MyMoneySecurity& security, QSqlQuery& q);
   void writePricePair(const MyMoneyPriceEntries& p);
   void writePrice(const MyMoneyPrice& p);
-  void writeCurrency(const MyMoneySecurity& currency, MyMoneySqlQuery& q);
-  void writeReport(const MyMoneyReport& rep, MyMoneySqlQuery& q);
-  void writeBudget(const MyMoneyBudget& bud, MyMoneySqlQuery& q);
+  void writeCurrency(const MyMoneySecurity& currency, QSqlQuery& q);
+  void writeReport(const MyMoneyReport& rep, QSqlQuery& q);
+  void writeBudget(const MyMoneyBudget& bud, QSqlQuery& q);
   void writeKeyValuePairs(const QString& kvpType, const QVariantList& kvpId, const QList<QMap<QString, QString> >& pairs);
 
   // read routines
@@ -341,10 +359,8 @@ private:
   void readUserInformation(void);
   void readInstitutions(void);
   void readAccounts(void);
-  void readTransaction(const QString id);
   void readTransactions(const QString& tidList = QString(), const QString& dateClause = QString());
-  void readTransaction(MyMoneyTransaction &tx, const QString& tid);
-  void readSplit(MyMoneySplit& s, const MyMoneySqlQuery& q) const;
+  void readSplit(MyMoneySplit& s, const QSqlQuery& q) const;
   const MyMoneyKeyValueContainer readKeyValuePairs(const QString& kvpType, const QString& kvpId) const;
   const QHash<QString, MyMoneyKeyValueContainer> readKeyValuePairs(const QString& kvpType, const QStringList& kvpIdList) const;
   void readSchedules(void);
@@ -396,20 +412,9 @@ private:
   int upgradeToV5();
   int upgradeToV6();
 
-  bool sqliteAlterTable(const MyMoneyDbTable& t);
-  bool addColumn(const MyMoneyDbTable& t, const MyMoneyDbColumn& c,
-                 const QString& after = QString());
-  bool addColumn(const QString& table,
-                 const QString& column,
-                 const QString& after = QString());
-  bool dropColumn(const MyMoneyDbTable& t,
-                  const QString& c);
-  bool dropColumn(const QString& table,
-                  const QString& column);
-
-//  long long unsigned getRecCount(const QString& table);
-  int createTables();
-  void createTable(const MyMoneyDbTable& t);
+  int createTables(int version = std::numeric_limits<int>::max());
+  void createTable(const MyMoneyDbTable& t, int version = std::numeric_limits<int>::max());
+  bool alterTable(const MyMoneyDbTable& t, int fromVersion);
   void clean();
   int isEmpty();
   // data
@@ -455,24 +460,6 @@ private:
 
   */
   bool m_displayStatus;
-  /**
-   * On occasions, e.g. after a complex transaction search, or for populating a
-   * payee popup list, it becomes necessary to load all data into memory. The
-   * following flags will be set after such a load, to indicate that further
-   * retrievals are not needed.
-   */
-//  bool m_transactionListRead;
-//  bool m_payeeListRead;
-  /**
-   * This member variable holds a list of those accounts for which all
-   * transactions are in memory, thus saving reading them again
-   */
-//  QList<QString> m_accountsLoaded;
-  /**
-    * This member variable is used when loading transactions to list all
-    * referenced payees, which can then be read into memory (if not already there)
-    */
-//  QList<QString> m_payeeList;
 
   void alert(QString s) const {
     qDebug() << s;
@@ -511,5 +498,17 @@ private:
   MyMoneyStorageSql(const MyMoneyStorageSql& rhs);
   MyMoneyStorageSql& operator= (const MyMoneyStorageSql& rhs);
   bool m_newDatabase;
+
+  /**
+    * This member keeps the current precision to be used fro prices.
+    * @sa setPrecision()
+    */
+  static int m_precision;
+
+  /**
+    * This member keeps the current start date used for transaction retrieval.
+    * @sa setStartDate()
+    */
+  static QDate m_startDate;
 };
 #endif // MYMONEYSTORAGESQL_H
