@@ -132,6 +132,7 @@ bool OfxImporterPlugin::isMyFormat(const QString& filename) const
 {
   // filename is considered an Ofx file if it contains
   // the tag "<OFX>" or "<OFC>" in the first 20 lines.
+  // which contain some data
   bool result = false;
 
   QFile f(filename);
@@ -140,11 +141,14 @@ bool OfxImporterPlugin::isMyFormat(const QString& filename) const
 
     int lineCount = 20;
     while (!ts.atEnd() && !result  && lineCount != 0) {
-      QString line = ts.readLine();
+      // get a line of data and remove all unnecessary whitepace chars
+      QString line = ts.readLine().simplified();
       if (line.contains("<OFX>", Qt::CaseInsensitive)
           || line.contains("<OFC>", Qt::CaseInsensitive))
         result = true;
-      lineCount--;
+      // count only lines that contain some non white space chars
+      if (!line.isEmpty())
+        lineCount--;
     }
     f.close();
   }
