@@ -45,6 +45,7 @@
 #include <KDChartCartesianAxis>
 #include <KDChartFrameAttributes>
 #include "kmymoneyglobalsettings.h"
+#include <kbalanceaxis.h>
 
 using namespace reports;
 
@@ -100,56 +101,49 @@ void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport
   // an account in a COLUMN, while line/bar prefer it in a ROW.
   setAccountSeries(true);
 
-  //what values should be shown
-  bool showBudget = config.hasBudget();
-  bool showForecast = config.isIncludingForecast();
-  bool showActual = false;
-  if ((config.isIncludingBudgetActuals()) || (!showBudget && !showForecast))
-    showActual = true;
-
   switch (config.chartType()) {
-  case MyMoneyReport::eChartNone:
-  case MyMoneyReport::eChartEnd:
-  case MyMoneyReport::eChartLine: {
-    KDChart::LineDiagram* diagram = new KDChart::LineDiagram;
-    CartesianCoordinatePlane* cartesianPlane = new CartesianCoordinatePlane;
-    replaceCoordinatePlane(cartesianPlane);
-    coordinatePlane()->replaceDiagram(diagram);
-    break;
-  }
-  case MyMoneyReport::eChartBar: {
-    KDChart::BarDiagram* diagram = new KDChart::BarDiagram;
-    CartesianCoordinatePlane* cartesianPlane = new CartesianCoordinatePlane;
-    replaceCoordinatePlane(cartesianPlane);
-    coordinatePlane()->replaceDiagram(diagram);
-    break;
-  }
-  case MyMoneyReport::eChartStackedBar: {
-    KDChart::BarDiagram* diagram = new KDChart::BarDiagram;
-    CartesianCoordinatePlane* cartesianPlane = new CartesianCoordinatePlane;
-    replaceCoordinatePlane(cartesianPlane);
-    diagram->setType(BarDiagram::Stacked);
-    coordinatePlane()->replaceDiagram(diagram);
-    break;
-  }
-  case MyMoneyReport::eChartPie: {
-    KDChart::PieDiagram* diagram = new KDChart::PieDiagram;
-    PolarCoordinatePlane* polarPlane = new PolarCoordinatePlane;
-    replaceCoordinatePlane(polarPlane);
-    coordinatePlane()->replaceDiagram(diagram);
-    setAccountSeries(false);
-    setSeriesTotals(true);
-    break;
-  }
-  case MyMoneyReport::eChartRing: {
-    KDChart::RingDiagram* diagram = new KDChart::RingDiagram;
-    PolarCoordinatePlane* polarPlane = new PolarCoordinatePlane;
-    replaceCoordinatePlane(polarPlane);
-    polarPlane->replaceDiagram(diagram);
-    //chartView.params()->setRelativeRingThickness( true );
-    setAccountSeries(false);
-    break;
-  }
+    case MyMoneyReport::eChartNone:
+    case MyMoneyReport::eChartEnd:
+    case MyMoneyReport::eChartLine: {
+        KDChart::LineDiagram* diagram = new KDChart::LineDiagram;
+        CartesianCoordinatePlane* cartesianPlane = new CartesianCoordinatePlane;
+        replaceCoordinatePlane(cartesianPlane);
+        coordinatePlane()->replaceDiagram(diagram);
+        break;
+      }
+    case MyMoneyReport::eChartBar: {
+        KDChart::BarDiagram* diagram = new KDChart::BarDiagram;
+        CartesianCoordinatePlane* cartesianPlane = new CartesianCoordinatePlane;
+        replaceCoordinatePlane(cartesianPlane);
+        coordinatePlane()->replaceDiagram(diagram);
+        break;
+      }
+    case MyMoneyReport::eChartStackedBar: {
+        KDChart::BarDiagram* diagram = new KDChart::BarDiagram;
+        CartesianCoordinatePlane* cartesianPlane = new CartesianCoordinatePlane;
+        replaceCoordinatePlane(cartesianPlane);
+        diagram->setType(BarDiagram::Stacked);
+        coordinatePlane()->replaceDiagram(diagram);
+        break;
+      }
+    case MyMoneyReport::eChartPie: {
+        KDChart::PieDiagram* diagram = new KDChart::PieDiagram;
+        PolarCoordinatePlane* polarPlane = new PolarCoordinatePlane;
+        replaceCoordinatePlane(polarPlane);
+        coordinatePlane()->replaceDiagram(diagram);
+        setAccountSeries(false);
+        setSeriesTotals(true);
+        break;
+      }
+    case MyMoneyReport::eChartRing: {
+        KDChart::RingDiagram* diagram = new KDChart::RingDiagram;
+        PolarCoordinatePlane* polarPlane = new PolarCoordinatePlane;
+        replaceCoordinatePlane(polarPlane);
+        polarPlane->replaceDiagram(diagram);
+        //chartView.params()->setRelativeRingThickness( true );
+        setAccountSeries(false);
+        break;
+      }
   }
   //get the diagram for later use
   AbstractDiagram* planeDiagram = coordinatePlane()->diagram();
@@ -195,7 +189,7 @@ void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport
     }
 
     //set y axis
-    CartesianAxis *yAxis = new CartesianAxis();
+    KBalanceAxis *yAxis = new KBalanceAxis();
     yAxis->setPosition(CartesianAxis::Left);
     yAxis->setTitleText(i18n("Balance"));
     TextAttributes yAxisTextAttr(yAxis->titleTextAttributes());
@@ -206,11 +200,6 @@ void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport
     if (config.chartType() == MyMoneyReport::eChartLine) {
       KDChart::LineDiagram* lineDiagram = qobject_cast<LineDiagram*>(planeDiagram);
 
-      //set line width
-      /*QPen linePen(lineDiagram->pen());
-      linePen.setWidth(config.chartLineWidth());
-      lineDiagram->setPen(linePen);*/
-
       //remove all existing axes before inserting new ones
       while (lineDiagram->axes().count() > 0) {
         CartesianAxis *delAxis  = lineDiagram->axes().at(0);
@@ -243,184 +232,184 @@ void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport
 
   ::timetrace("loading rows");
   switch (config.detailLevel()) {
-  case MyMoneyReport::eDetailNone:
-  case MyMoneyReport::eDetailEnd:
-  case MyMoneyReport::eDetailAll: {
-    int rowNum = 0;
+    case MyMoneyReport::eDetailNone:
+    case MyMoneyReport::eDetailEnd:
+    case MyMoneyReport::eDetailAll: {
+        int rowNum = 0;
 
-    // iterate over outer groups
-    PivotGrid::const_iterator it_outergroup = grid.begin();
-    while (it_outergroup != grid.end()) {
-      // iterate over inner groups
-      PivotOuterGroup::const_iterator it_innergroup = (*it_outergroup).begin();
-      while (it_innergroup != (*it_outergroup).end()) {
-        //
-        // Rows
-        //
-        QString innergroupdata;
-        PivotInnerGroup::const_iterator it_row = (*it_innergroup).begin();
-        while (it_row != (*it_innergroup).end()) {
-          //Do not include investments accounts in the chart because they are merely container of stock and other accounts
-          if (it_row.key().accountType() != MyMoneyAccount::Investment) {
+        // iterate over outer groups
+        PivotGrid::const_iterator it_outergroup = grid.begin();
+        while (it_outergroup != grid.end()) {
+          // iterate over inner groups
+          PivotOuterGroup::const_iterator it_innergroup = (*it_outergroup).begin();
+          while (it_innergroup != (*it_outergroup).end()) {
+            //
+            // Rows
+            //
+            QString innergroupdata;
+            PivotInnerGroup::const_iterator it_row = (*it_innergroup).begin();
+            while (it_row != (*it_innergroup).end()) {
+              //Do not include investments accounts in the chart because they are merely container of stock and other accounts
+              if (it_row.key().accountType() != MyMoneyAccount::Investment) {
+                //iterate row types
+                for (int i = 0; i < rowTypeList.size(); ++i) {
+                  //skip the budget difference rowset
+                  if (rowTypeList[i] != eBudgetDiff) {
+                    QString legendText;
+
+                    //only show the column type in the header if there is more than one type
+                    if (rowTypeList.size() > 1) {
+                      legendText = QString(columnTypeHeaderList[i] + " - " + it_row.key().name());
+                    } else {
+                      legendText = QString(it_row.key().name());
+                    }
+
+                    //set the cell value and tooltip
+                    rowNum = drawPivotRowSet(rowNum, it_row.value(), rowTypeList[i], legendText, 1, numColumns());
+
+                    //set the legend text
+                    legend->setText(rowNum - 1, legendText);
+                  }
+                }
+              }
+              ++it_row;
+            }
+            ++it_innergroup;
+          }
+          ++it_outergroup;
+        }
+      }
+      break;
+
+    case MyMoneyReport::eDetailTop: {
+        int rowNum = 0;
+
+        // iterate over outer groups
+        PivotGrid::const_iterator it_outergroup = grid.begin();
+        while (it_outergroup != grid.end()) {
+
+          // iterate over inner groups
+          PivotOuterGroup::const_iterator it_innergroup = (*it_outergroup).begin();
+          while (it_innergroup != (*it_outergroup).end()) {
             //iterate row types
             for (int i = 0; i < rowTypeList.size(); ++i) {
               //skip the budget difference rowset
               if (rowTypeList[i] != eBudgetDiff) {
                 QString legendText;
 
+
                 //only show the column type in the header if there is more than one type
                 if (rowTypeList.size() > 1) {
-                  legendText = QString(columnTypeHeaderList[i] + " - " + it_row.key().name());
+                  legendText = QString(columnTypeHeaderList[i] + " - " + it_innergroup.key());
                 } else {
-                  legendText = QString(it_row.key().name());
+                  legendText = QString(it_innergroup.key());
                 }
 
                 //set the cell value and tooltip
-                rowNum = drawPivotRowSet(rowNum, it_row.value(), rowTypeList[i], legendText, 1, numColumns());
+                rowNum = drawPivotRowSet(rowNum, (*it_innergroup).m_total, rowTypeList[i], legendText, 1, numColumns());
 
                 //set the legend text
                 legend->setText(rowNum - 1, legendText);
               }
             }
+            ++it_innergroup;
           }
-          ++it_row;
+          ++it_outergroup;
         }
-        ++it_innergroup;
       }
-      ++it_outergroup;
-    }
-  }
-  break;
+      break;
 
-  case MyMoneyReport::eDetailTop: {
-    int rowNum = 0;
+    case MyMoneyReport::eDetailGroup: {
+        int rowNum = 0;
 
-    // iterate over outer groups
-    PivotGrid::const_iterator it_outergroup = grid.begin();
-    while (it_outergroup != grid.end()) {
+        // iterate over outer groups
+        PivotGrid::const_iterator it_outergroup = grid.begin();
+        while (it_outergroup != grid.end()) {
+          //iterate row types
+          for (int i = 0; i < rowTypeList.size(); ++i) {
+            //skip the budget difference rowset
+            if (rowTypeList[i] != eBudgetDiff) {
+              QString legendText;
+
+              //only show the column type in the header if there is more than one type
+              if (rowTypeList.size() > 1) {
+                legendText = QString(columnTypeHeaderList[i] + " - " + it_outergroup.key());
+              } else {
+                legendText = QString(it_outergroup.key());
+              }
+
+              //set the cell value and tooltip
+              rowNum = drawPivotRowSet(rowNum, (*it_outergroup).m_total, rowTypeList[i], legendText, 1, numColumns());
+
+              //set the legend
+              legend->setText(rowNum - 1, legendText);
+            }
+          }
+          ++it_outergroup;
+        }
+
+        //if selected, show totals too
+        if (config.isShowingRowTotals()) {
+          //iterate row types
+          for (int i = 0; i < rowTypeList.size(); ++i) {
+            //skip the budget difference rowset
+            if (rowTypeList[i] != eBudgetDiff) {
+              QString legendText;
+
+              //only show the column type in the header if there is more than one type
+              if (rowTypeList.size() > 1) {
+                legendText = QString(columnTypeHeaderList[i] + " - " + i18nc("Total balance", "Total"));
+              } else {
+                legendText = QString(i18nc("Total balance", "Total"));
+              }
+
+              //set the cell value
+              rowNum = drawPivotRowSet(rowNum, grid.m_total, rowTypeList[i], legendText, 1, numColumns());
+
+              //set the legend
+              legend->setText(rowNum - 1, legendText);
+
+            }
+          }
+        }
+      }
+      break;
+
+    case MyMoneyReport::eDetailTotal: {
+        int rowNum = 0;
 
-      // iterate over inner groups
-      PivotOuterGroup::const_iterator it_innergroup = (*it_outergroup).begin();
-      while (it_innergroup != (*it_outergroup).end()) {
         //iterate row types
         for (int i = 0; i < rowTypeList.size(); ++i) {
           //skip the budget difference rowset
           if (rowTypeList[i] != eBudgetDiff) {
             QString legendText;
 
-
             //only show the column type in the header if there is more than one type
             if (rowTypeList.size() > 1) {
-              legendText = QString(columnTypeHeaderList[i] + " - " + it_innergroup.key());
+              legendText = QString(columnTypeHeaderList[i] + " - " + i18nc("Total balance", "Total"));
             } else {
-              legendText = QString(it_innergroup.key());
+              legendText = QString(i18nc("Total balance", "Total"));
             }
 
-            //set the cell value and tooltip
-            rowNum = drawPivotRowSet(rowNum, (*it_innergroup).m_total, rowTypeList[i], legendText, 1, numColumns());
+            if (config.isMixedTime() && (rowTypeList[i] == eActual || rowTypeList[i] == eForecast)) {
+              if (rowTypeList[i] == eActual) {
+                rowNum = drawPivotRowSet(rowNum, grid.m_total, rowTypeList[i], legendText, 1, config.currentDateColumn());
+              } else if (rowTypeList[i] == eForecast) {
+                rowNum = drawPivotRowSet(rowNum, grid.m_total, rowTypeList[i], legendText, config.currentDateColumn(), numColumns());
+              } else {
+                rowNum = drawPivotRowSet(rowNum, grid.m_total, rowTypeList[i], legendText, 1, numColumns());
+              }
+            } else {
+              //set cell value
+              rowNum = drawPivotRowSet(rowNum, grid.m_total, rowTypeList[i], legendText, 1, numColumns());
+            }
 
-            //set the legend text
+            //set legend text
             legend->setText(rowNum - 1, legendText);
           }
         }
-        ++it_innergroup;
       }
-      ++it_outergroup;
-    }
-  }
-  break;
-
-  case MyMoneyReport::eDetailGroup: {
-    int rowNum = 0;
-
-    // iterate over outer groups
-    PivotGrid::const_iterator it_outergroup = grid.begin();
-    while (it_outergroup != grid.end()) {
-      //iterate row types
-      for (int i = 0; i < rowTypeList.size(); ++i) {
-        //skip the budget difference rowset
-        if (rowTypeList[i] != eBudgetDiff) {
-          QString legendText;
-
-          //only show the column type in the header if there is more than one type
-          if (rowTypeList.size() > 1) {
-            legendText = QString(columnTypeHeaderList[i] + " - " + it_outergroup.key());
-          } else {
-            legendText = QString(it_outergroup.key());
-          }
-
-          //set the cell value and tooltip
-          rowNum = drawPivotRowSet(rowNum, (*it_outergroup).m_total, rowTypeList[i], legendText, 1, numColumns());
-
-          //set the legend
-          legend->setText(rowNum - 1, legendText);
-        }
-      }
-      ++it_outergroup;
-    }
-
-    //if selected, show totals too
-    if (config.isShowingRowTotals()) {
-      //iterate row types
-      for (int i = 0; i < rowTypeList.size(); ++i) {
-        //skip the budget difference rowset
-        if (rowTypeList[i] != eBudgetDiff) {
-          QString legendText;
-
-          //only show the column type in the header if there is more than one type
-          if (rowTypeList.size() > 1) {
-            legendText = QString(columnTypeHeaderList[i] + " - " + i18nc("Total balance", "Total"));
-          } else {
-            legendText = QString(i18nc("Total balance", "Total"));
-          }
-
-          //set the cell value
-          rowNum = drawPivotRowSet(rowNum, grid.m_total, rowTypeList[i], legendText, 1, numColumns());
-
-          //set the legend
-          legend->setText(rowNum - 1, legendText);
-
-        }
-      }
-    }
-  }
-  break;
-
-  case MyMoneyReport::eDetailTotal: {
-    int rowNum = 0;
-
-    //iterate row types
-    for (int i = 0; i < rowTypeList.size(); ++i) {
-      //skip the budget difference rowset
-      if (rowTypeList[i] != eBudgetDiff) {
-        QString legendText;
-
-        //only show the column type in the header if there is more than one type
-        if (rowTypeList.size() > 1) {
-          legendText = QString(columnTypeHeaderList[i] + " - " + i18nc("Total balance", "Total"));
-        } else {
-          legendText = QString(i18nc("Total balance", "Total"));
-        }
-
-        if (config.isMixedTime() && (rowTypeList[i] == eActual || rowTypeList[i] == eForecast)) {
-          if (rowTypeList[i] == eActual) {
-            rowNum = drawPivotRowSet(rowNum, grid.m_total, rowTypeList[i], legendText, 1, config.currentDateColumn());
-          } else if (rowTypeList[i] == eForecast) {
-            rowNum = drawPivotRowSet(rowNum, grid.m_total, rowTypeList[i], legendText, config.currentDateColumn(), numColumns());
-          } else {
-            rowNum = drawPivotRowSet(rowNum, grid.m_total, rowTypeList[i], legendText, 1, numColumns());
-          }
-        } else {
-          //set cell value
-          rowNum = drawPivotRowSet(rowNum, grid.m_total, rowTypeList[i], legendText, 1, numColumns());
-        }
-
-        //set legend text
-        legend->setText(rowNum - 1, legendText);
-      }
-    }
-  }
-  break;
+      break;
   }
   ::timetrace("rows loaded");
 
@@ -448,7 +437,7 @@ void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport
     //if it is over the limit delete the legend
     takeLegend(legend);
     delete legend;
-    if(legends().size()) {
+    if (legends().size()) {
       Legend* initialLegend = legends().at(0);
       takeLegend(initialLegend);
       delete initialLegend;
@@ -559,22 +548,35 @@ void KReportChartView::setLineWidth(const int lineWidth)
   if (qobject_cast<LineDiagram*>(coordinatePlane()->diagram())) {
     LineDiagram* lineDiagram = qobject_cast<LineDiagram*>(coordinatePlane()->diagram());
     const int currentCols = m_model.columnCount();
+    const int currentRows = m_model.rowCount();
     for (int col = 0; col < currentCols; ++col) {
-      QPen pen = lineDiagram->pen(col);
-      pen.setWidth(lineWidth);
-      lineDiagram->setPen(col, pen);
+      for (int row = 0; row < currentRows; ++row) {
+        QPen pen(lineDiagram->pen(m_model.index(row, col, QModelIndex())));
+        pen.setWidth(lineWidth);
+        lineDiagram->setPen(m_model.index(row, col, QModelIndex()), pen);
+      }
     }
   }
 }
 
 void KReportChartView::drawLimitLine(const double limit)
 {
+  // temporarily disconnect the view from the model to aovid update of view on
+  // emission of the dataChanged() signal for each call of setDataCell().
+  // This speeds up the runtime of drawLimitLine() by a factor of
+  // approx. 60 on my box (1831ms vs. 31ms).
+  AbstractDiagram* planeDiagram = coordinatePlane()->diagram();
+  planeDiagram->setModel(0);
+
   //we get the current number of rows and we add one after that
   int row = m_model.rowCount();
 
   for (int col = 0; col < m_numColumns; ++col) {
     setDataCell(col, row, limit);
   }
+
+  planeDiagram->setModel(&m_model);
+
 //TODO: add format to the line
 }
 
