@@ -91,7 +91,7 @@ KPayeesView::KPayeesView(QWidget *parent) :
     m_needConnection(true),
     m_updatesQueued(0),
     m_inSelection(false),
-    m_payeeInEditing(false)
+    m_allowEditing(true)
 {
   setupUi(this);
 
@@ -166,6 +166,7 @@ KPayeesView::KPayeesView(QWidget *parent) :
 
   connect(m_payeesList, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(slotSelectPayee()));
   connect(m_payeesList, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(slotSelectPayee()));
+  connect(m_payeesList, SIGNAL(currentItemChanged(QListWidgetItem*, QListWidgetItem*)), this, SLOT(slotSelectPayee()));
   connect(m_payeesList, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(slotStartRename(QListWidgetItem*)));
   connect(m_payeesList, SIGNAL(itemChanged(QListWidgetItem*)), this, SLOT(slotRenamePayee(QListWidgetItem*)));
 
@@ -225,23 +226,27 @@ void KPayeesView::slotChooseDefaultAccount(void)
 
   KMyMoneyRegister::RegisterItem* item = m_register->firstItem();
   while (item) {
-    KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(item);
-    item = item->nextItem();
-    MyMoneySplit s = t->transaction().splitByPayee(m_payee.id());
-    const MyMoneyAccount& acc = file->account(s.accountId());
+    //only walk through selectable items. eg. transactions and not group markers
+    if (item->isSelectable()) {
+      KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(item);
 
-    QString txt;
-    if (s.action() != MyMoneySplit::ActionAmortization
-        && acc.accountType() != MyMoneyAccount::AssetLoan
-        && !file->isTransfer(t->transaction())
-        && t->transaction().splitCount() == 2) {
-      MyMoneySplit s0 = t->transaction().splitByAccount(s.accountId(), false);
-      if (account_count.contains(s0.accountId())) {
-        account_count[s0.accountId()]++;
-      } else {
-        account_count[s0.accountId()] = 1;
+      MyMoneySplit s = t->transaction().splitByPayee(m_payee.id());
+      const MyMoneyAccount& acc = file->account(s.accountId());
+
+      QString txt;
+      if (s.action() != MyMoneySplit::ActionAmortization
+          && acc.accountType() != MyMoneyAccount::AssetLoan
+          && !file->isTransfer(t->transaction())
+          && t->transaction().splitCount() == 2) {
+        MyMoneySplit s0 = t->transaction().splitByAccount(s.accountId(), false);
+        if (account_count.contains(s0.accountId())) {
+          account_count[s0.accountId()]++;
+        } else {
+          account_count[s0.accountId()] = 1;
+        }
       }
     }
+    item = item->nextItem();
   }
 
   QMap<QString, int>::Iterator most_frequent, iter;
@@ -260,7 +265,7 @@ void KPayeesView::slotChooseDefaultAccount(void)
 
 void KPayeesView::slotStartRename(QListWidgetItem* item)
 {
-  m_payeeInEditing = true;
+  m_allowEditing = true;
   m_payeesList->editItem(item);
 }
 
@@ -276,10 +281,9 @@ void KPayeesView::slotRenameButtonCliked()
 void KPayeesView::slotRenamePayee(QListWidgetItem* p)
 {
   //if there is no current item selected, exit
-  if (m_payeeInEditing == false || !m_payeesList->currentItem() || p != m_payeesList->currentItem())
+  if (m_allowEditing == false || !m_payeesList->currentItem() || p != m_payeesList->currentItem())
     return;
 
-  m_payeeInEditing = false;
   //kDebug() << "[KPayeesView::slotRenamePayee]";
   // create a copy of the new name without appended whitespaces
   QString new_name = p->text();
@@ -356,7 +360,7 @@ void KPayeesView::selectedPayees(QList<MyMoneyPayee>& payeesList) const
 
 void KPayeesView::slotSelectPayee(void)
 {
-  m_payeeInEditing = false;
+  m_allowEditing = false;
 
   // check if the content of a currently selected payee was modified
   // and ask to store the data
@@ -441,6 +445,7 @@ void KPayeesView::slotSelectPayee(void)
     m_payee = MyMoneyPayee();
     delete e;
   }
+  m_allowEditing = true;
 }
 
 void KPayeesView::clearItemData(void)
@@ -455,7 +460,7 @@ void KPayeesView::clearItemData(void)
 
 void KPayeesView::showTransactions(void)
 {
-  MyMoneyMoney balance(0);
+  MyMoneyMoney balance;
 
   // setup sort order
   m_register->setSortOrder(KMyMoneyGlobalSettings::sortSearchView());
@@ -675,6 +680,7 @@ void KPayeesView::loadPayees(void)
   if (currentItem)
     id = currentItem->payee().id();
 
+  m_allowEditing = false;
   // clear the list
   m_payeesList->clear();
   m_register->clear();
@@ -703,6 +709,7 @@ void KPayeesView::loadPayees(void)
   comboDefaultAccount->expandAll();
 
   slotSelectPayee();
+  m_allowEditing = true;
 
   ::timetrace("End KPayeesView::loadPayees");
 }
