@@ -43,6 +43,8 @@
 KMyMoneySelector::KMyMoneySelector(QWidget *parent, Qt::WFlags flags) :
     QWidget(parent, flags)
 {
+  setAutoFillBackground(true);
+
   m_selMode = QTreeWidget::SingleSelection;
 
   m_treeWidget = new QTreeWidget(this);
@@ -52,11 +54,6 @@ KMyMoneySelector::KMyMoneySelector(QWidget *parent, Qt::WFlags flags) :
   m_treeWidget->setSortingEnabled(false);
   m_treeWidget->setAlternatingRowColors(true);
 
-  if (parent) {
-    setFocusProxy(parent->focusProxy());
-    m_treeWidget->setFocusProxy(parent->focusProxy());
-  }
-
   m_treeWidget->setAllColumnsShowFocus(true);
 
   m_layout = new QHBoxLayout(this);
@@ -355,13 +352,13 @@ void KMyMoneySelector::setSelected(const QString& id, const bool state)
   QTreeWidgetItem* it_visible = 0;
 
   while ((item = *it) != 0) {
-    if (item->flags().testFlag(Qt::ItemIsUserCheckable)) {
-      if (item->data(0, IdRole).toString() == id) {
+    if (item->data(0, IdRole).toString() == id) {
+      if (item->flags().testFlag(Qt::ItemIsUserCheckable)) {
         item->setCheckState(0, state ? Qt::Checked : Qt::Unchecked);
-        m_treeWidget->setCurrentItem(item);
-        if (!it_visible)
-          it_visible = item;
       }
+      m_treeWidget->setCurrentItem(item);
+      if (!it_visible)
+        it_visible = item;
     }
     it++;
   }
