@@ -1407,6 +1407,10 @@ void Register::mouseReleaseEvent(QMouseEvent *e)
 void Register::contextMenuEvent(QContextMenuEvent *e)
 {
   if (e->reason() == QContextMenuEvent::Mouse) {
+    // since mouse release event is not called,
+    // we need to fake the right mouse button release here
+    m_mouseButton = Qt::RightButton;
+
     // if a selected item is clicked don't change the selection
     RegisterItem* item = itemAtRow(rowAt(e->y()));
     if (item && !item->isSelected())
@@ -1707,8 +1711,10 @@ void Register::removeEditWidgets(QMap<QString, QWidget*>& editWidgets)
   KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(focusItem());
   for (int row = t->startRow(); row < t->startRow() + t->numRowsRegister(true); ++row) {
     for (int col = 0; col < columnCount(); ++col) {
-      if (cellWidget(row, col))
+      if (cellWidget(row, col)) {
+        cellWidget(row, col)->hide();
         setCellWidget(row, col, 0);
+      }
     }
     // make sure to reduce the possibly size to what it was before editing started
     setRowHeight(row, t->rowHeightHint());
@@ -1883,6 +1889,9 @@ void Register::scrollPage(int key, Qt::KeyboardModifiers modifiers)
 
   if (item->isSelectable()) {
     handleItemChange(oldFocusItem, modifiers & Qt::ShiftModifier, modifiers & Qt::ControlModifier);
+    // tell the world about the changes in selection
+    SelectedTransactions list(this);
+    emit selectionChanged(list);
   }
 
   if (m_focusItem && !m_focusItem->isSelected() && m_selectionMode == SingleSelection)
