@@ -18,11 +18,6 @@
 #ifndef REGISTER_H
 #define REGISTER_H
 
-// Some STL headers in GCC4.3 contain operator new. Memory checker mangles these
-#ifdef _CHECK_MEMORY
-#undef new
-#endif
-
 #include <algorithm>
 
 // ----------------------------------------------------------------------------
@@ -40,6 +35,7 @@
 #include <QDropEvent>
 #include <QFocusEvent>
 #include <QMouseEvent>
+#include <QScrollBar>
 #include <QStyledItemDelegate>
 
 // ----------------------------------------------------------------------------
@@ -47,9 +43,6 @@
 
 // ----------------------------------------------------------------------------
 // Project Includes
-#ifdef _CHECK_MEMORY
-#include <mymoneyutils.h>
-#endif
 
 #include <mymoneyaccount.h>
 #include <registeritem.h>
@@ -77,10 +70,15 @@ typedef enum {
 } TransactionSortField;
 
 typedef enum {
-  AscendingOrder = 0,        //< sort in ascending order
-  DescendingOrder            //< sort in descending order
+  AscendingOrder = 0,   //< sort in ascending order
+  DescendingOrder       //< sort in descending order
 } SortDirection;
 
+typedef enum {
+  PayeeFirst = 0,       //< show the payee on the first row of the transaction in the details column and the account on the second
+  AccountFirst          //< show the account on the first row of the transaction in the details column and the payee on the second
+} DetailsColumnType;
+
 class Register;
 class RegisterItem;
 class ItemPtrVector;
@@ -500,6 +498,9 @@ public:
     m_selectionMode = mode;
   }
 
+  DetailsColumnType getDetailsColumnType() const;
+  void setDetailsColumnType(DetailsColumnType detailsColumnType);
+
 protected:
 
   void mouseReleaseEvent(QMouseEvent *e);
@@ -518,6 +519,7 @@ protected:
   void focusOutEvent(QFocusEvent*);
   void focusInEvent(QFocusEvent*);
   void keyPressEvent(QKeyEvent*);
+  virtual void resizeEvent(QResizeEvent* ev);
 
   int rowToIndex(int row) const;
   void setupItemIndex(int rowCount);
@@ -528,10 +530,10 @@ protected:
     * The height to scroll is determined by visibleHeight()
     *
     * @param key Qt::Page_Up or Qt::Page_Down depending on the direction to scroll
-    * @param state state of Qt::ShiftModifier, Qt::ControlModifier, Qt::AltModifier and
+    * @param modifiers state of Qt::ShiftModifier, Qt::ControlModifier, Qt::AltModifier and
     *              Qt::MetaModifier.
     */
-  void scrollPage(int key, Qt::ButtonState state);
+  void scrollPage(int key, Qt::KeyboardModifiers modifiers);
 
   /**
     * This method determines the pointer to a RegisterItem
@@ -610,7 +612,7 @@ signals:
 
 protected:
   ItemPtrVector                m_items;
-  QVector<RegisterItem*>  m_itemIndex;
+  QVector<RegisterItem*>       m_itemIndex;
   RegisterItem*                m_selectAnchor;
   RegisterItem*                m_focusItem;
   RegisterItem*                m_ensureVisibleItem;
@@ -632,11 +634,13 @@ private:
   bool                         m_listsDirty;
   bool                         m_ignoreNextButtonRelease;
   bool                         m_needInitialColumnResize;
-  Qt::ButtonState              m_buttonState;
+  Qt::MouseButtons             m_mouseButton;
+  Qt::KeyboardModifiers        m_modifiers;
   Column                       m_lastCol;
   QList<TransactionSortField>  m_sortOrder;
   QRect                        m_lastRepaintRect;
   RegisterItemDelegate        *m_itemDelegate;
+  DetailsColumnType            m_detailsColumnType;
 };
 
 } // namespace
