@@ -1219,8 +1219,8 @@ LoanPaymentPage::LoanPaymentPage(Wizard* wizard) :
   d->phonyAccount = MyMoneyAccount(QString("Phony-ID"), MyMoneyAccount());
 
   d->phonySplit.setAccountId(d->phonyAccount.id());
-  d->phonySplit.setValue(MyMoneyMoney(0));
-  d->phonySplit.setShares(MyMoneyMoney(0));
+  d->phonySplit.setValue(MyMoneyMoney());
+  d->phonySplit.setShares(MyMoneyMoney());
 
   d->additionalFeesTransaction.addSplit(d->phonySplit);
 
@@ -1274,7 +1274,7 @@ void LoanPaymentPage::enterPage(void)
 void LoanPaymentPage::slotAdditionalFees(void)
 {
   QMap<QString, MyMoneyMoney> priceInfo;
-  QPointer<KSplitTransactionDlg> dlg = new KSplitTransactionDlg(d->additionalFeesTransaction, d->phonySplit, d->phonyAccount, false, !m_wizard->moneyBorrowed(), MyMoneyMoney(0), priceInfo);
+  QPointer<KSplitTransactionDlg> dlg = new KSplitTransactionDlg(d->additionalFeesTransaction, d->phonySplit, d->phonyAccount, false, !m_wizard->moneyBorrowed(), MyMoneyMoney(), priceInfo);
 
   // connect(dlg, SIGNAL(newCategory(MyMoneyAccount&)), this, SIGNAL(newCategory(MyMoneyAccount&)));
 
@@ -1283,7 +1283,7 @@ void LoanPaymentPage::slotAdditionalFees(void)
     // sum up the additional fees
     QList<MyMoneySplit>::ConstIterator it;
 
-    d->additionalFees = MyMoneyMoney(0);
+    d->additionalFees = MyMoneyMoney();
     for (it = d->additionalFeesTransaction.splits().constBegin(); it != d->additionalFeesTransaction.splits().constEnd(); ++it) {
       if ((*it).accountId() != d->phonyAccount.id()) {
         d->additionalFees += (*it).shares();
@@ -1461,7 +1461,7 @@ HierarchyFilterProxyModel::HierarchyFilterProxyModel(QObject *parent)
   */
 bool HierarchyFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
-  if (!source_parent.isValid() && source_row == 0) {
+  if (!source_parent.isValid()) {
     QVariant data = sourceModel()->data(sourceModel()->index(source_row, 0, source_parent), AccountsModel::AccountIdRole);
     if (data.isValid() && data.toString() == AccountsModel::favoritesAccountId)
       return false;
@@ -1493,12 +1493,12 @@ HierarchyPage::HierarchyPage(Wizard* wizard) :
   m_filterProxyModel->addAccountGroup(MyMoneyAccount::Liability);
   m_filterProxyModel->setSourceModel(Models::instance()->accountsModel());
   m_filterProxyModel->setDynamicSortFilter(true);
-  m_filterProxyModel->sort(0);
 
   m_parentAccounts->setAlternatingRowColors(true);
   m_parentAccounts->setIconSize(QSize(22, 22));
   m_parentAccounts->setSortingEnabled(true);
   m_parentAccounts->setModel(m_filterProxyModel);
+  m_parentAccounts->sortByColumn(0, Qt::AscendingOrder);
 
   connect(m_parentAccounts->selectionModel(), SIGNAL(currentChanged(QModelIndex, QModelIndex)), this, SLOT(parentAccountChanged()));
 }
